Robot Monitoring Tools 문서
===========================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   modules/tools
   modules/agent

Tools
-----
.. automodule:: robot_monitoring_tools.tools.battery_tool
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: robot_monitoring_tools.tools.transfer_date_tool
   :members:
   :undoc-members:
   :show-inheritance:

Agent
-----
.. automodule:: robot_monitoring_tools.agents.agent_client
   :members:
   :undoc-members:
   :show-inheritance: